#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

%global		package_version 3.5.0_master
%global		package_name ovirt-image-uploader
# Required users and groups
%global		vdsm_user vdsm
%global		vdsm_group kvm

%define         enable_autotools 1

Summary:	Image Uploader for Red Hat Enterprise Virtualization
Name:		rhevm-image-uploader
Version:	3.5.0
Release:	0.3.beta%{?release_suffix}%{?dist}
License:	ASL 2.0
URL:		http://www.redhat.com/virtualization/rhev/server/
Source:		http://resources.ovirt.org/pub/ovirt-3.5-snapshot/src/%{package_name}/%{package_name}-%{package_version}.tar.gz
Group:		Virtualization/Management

BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}
BuildArch:	noarch
Requires:	python
Requires:	python-lxml
Requires(pre):	shadow-utils
Requires:	rhevm-sdk-python >= 3.5.0.2
Requires:	logrotate
BuildRequires:	gettext
BuildRequires:	python2-devel
BuildRequires:	python-lxml
BuildRequires:  autoconf
BuildRequires:  automake

Patch1: 0001-upload-adding-ignore-lsc-CLI-options.patch
Patch2: 0002-ovirt-image-uploader-Add-creation-of-VDSM-user.patch
Patch3: 0003-ovirt-image-uploader-Add-creation-of-KVM-group.patch
Patch4: 0004-ovirt-image-uploader-fixing-usage-of-API-SDK-insecur.patch

%description
Image Uploader tool for Red Hat Enterprise Virtualization Manager

%prep
%setup -q -n %{package_name}-%{package_version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1


%build
%if 0%{?enable_autotools}
autoreconf -ivf
%endif
%configure \
	--docdir="%{_docdir}/%{package_name}-%{version}" \
	--disable-python-syntax-check

make %{?_smp_mflags}

%check
make check

%pre
getent group %{vdsm_group} >/dev/null || \
	LC_ALL=C groupadd -g 36 -r %{vdsm_group}
getent passwd %{vdsm_user} >/dev/null || \
	LC_ALL=C useradd -r -u 36 -g %{vdsm_group} -d / \
		-s /sbin/nologin -c "Node Virtualization Manager" %{vdsm_user}

%install
rm -rf "%{buildroot}"
make %{?_smp_mflags} install DESTDIR="%{buildroot}"
ln -s engine-image-uploader %{buildroot}/%{_bindir}/rhevm-image-uploader
echo ".so man8/engine-image-uploader.8" > %{buildroot}/%{_mandir}/man8/rhevm-image-uploader.8

%files
%doc AUTHORS
%doc COPYING
%dir %{_localstatedir}/log/ovirt-engine/%{package_name}
%dir %{_sysconfdir}/ovirt-engine/imageuploader.conf.d
%attr(0640, -, -) %config(noreplace) %{_sysconfdir}/ovirt-engine/imageuploader.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{package_name}
%{python_sitelib}/ovirt_image_uploader/*.py*
%{python_sitelib}/ovirt_image_uploader/ovf/*.py*
%{_bindir}/engine-image-uploader
%{_mandir}/man8/*
%{_bindir}/rhevm-image-uploader

%changelog
* Wed Sep 10 2014 Sandro Bonazzola <sbonazzo@redhat.com> - 3.5.0-0.3.beta
- Resolves: BZ#1136434

* Thu Aug 21 2014 Sandro Bonazzola <sbonazzo@redhat.com> - 3.5.0-0.2.master
- Resolves: BZ#1119798

* Fri Jul 11 2014 Sandro Bonazzola <sbonazzo@redhat.com> - 3.5.0-0.1.ovirtbeta2
- Rebase on upstream beta 2 release
- Resolves: BZ#1102226

